﻿using UnityEngine;
using System.Collections;
using Sirenix.OdinInspector;
using Sirenix.Serialization;
using System.Collections.Generic;
using Sirenix.OdinInspector.Editor;
using UnityEditor.SceneManagement;

public class OdinTest : SerializedMonoBehaviour
{
    public int generateCount = 3;

    [FoldoutGroup("Generated"), ReadOnly, OdinSerialize] MeshFilter[] meshFilters;
    [FoldoutGroup("Generated"), ReadOnly, OdinSerialize] Transform container;
    [FoldoutGroup("Generated"), ReadOnly, OdinSerialize]
    Dictionary<MeshFilter, MeshRenderer> renderers
        = new Dictionary<MeshFilter, MeshRenderer>();

    [Button(ButtonSizes.Large), HorizontalGroup] void Generate()
    {
        Clear();

        container = new GameObject("Container").transform;
        container.SetParent(transform);

        meshFilters = new MeshFilter[generateCount];
        for (int i = 0; i < generateCount; i++)
        {
            var obj = new GameObject("Object " + i);
            obj.transform.SetParent(container);

            meshFilters[i] = obj.AddComponent<MeshFilter>();
            var renderer = obj.AddComponent<MeshRenderer>();

            renderers[meshFilters[i]] = renderer;
        }

        OdinPrefabUtility.UpdatePrefabInstancePropertyModifications(this, false);
        EditorSceneManager.MarkSceneDirty(EditorSceneManager.GetActiveScene());
    }

    [Button(ButtonSizes.Large), HorizontalGroup] void Clear()
    {
        if (container != null) GameObject.DestroyImmediate(container.gameObject);
        foreach (var meshFilter in renderers.Keys)
        {
            GameObject.DestroyImmediate(meshFilter.gameObject);
        }
    }
}
